# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/demisgr/auto/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/demisgr/auto/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Demisgr\\Auto\\": "packages/demisgr/auto/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Demisgr\Auto\Providers\AutoServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Auto'  => Demisgr\Auto\Facades\Auto::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Demisgr\\AutoTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Demisgr\Auto\Providers\AutoServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Demisgr\Auto\Providers\AutoServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Demisgr\Auto\Providers\AutoServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/auto/{modulename}

**User**

    http://path-to-route-folder/user/auto/{modulename}

**Public**

    http://path-to-route-folder/autos


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/auto/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/auto/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/auto/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/auto/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/auto/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/auto/{modulename}/{slug}
    METHOD: GET